PUBSUB_NAME_EMBEDDING = "pubsub"
SECRET_STORE_NAME = "secretstore"
TOPIC_USER_INPUT_FOLDER = "user-input-folder"
STATE_STORE_NAME = "statestore"
TOPIC_DOWNLOAD_AND_EMBED = "download-and-embed"
STORAGE_NAME = "storage"
MAX_WORKERS = 50
MAX_EMPTY_CHECKS = 10
CHARS_PER_PAGE = 2000
FAST_API_TIMEOUT = 600
QUDRANT_ACTION_TIMEOUT = 60
MAX_CONCURRENT_PROCESS_FILES = 50
